Merge pull request #373 from gargrahul/fix_function_not_found_tex_drv_sample

Fixed function not found issue in texture driver api sample
This commit is contained in:
Maneesh Gupta
2018-03-19 14:11:28 +05:30
zatwierdzone przez GitHub
2 zmienionych plików z 2 dodań i 3 usunięć
@@ -23,7 +23,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern texture<float, 2, hipReadModeElementType> tex;
__global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
outputData[y * width + x] = tex2D(tex, x, y);
@@ -27,7 +27,7 @@ THE SOFTWARE.
#include <vector>
#include <hip/hip_hcc.h>
#define fileName "tex2dKernel.code"
#define fileName "tex2dKernel.code.adipose"
texture<float, 2, hipReadModeElementType> tex;
bool testResult = false;
@@ -90,7 +90,6 @@ bool runTest(int argc, char** argv) {
#ifdef __HIP_PLATFORM_HCC__
struct {
uint32_t _hidden[6]; // genco path + wrapper-gen pass used hidden arguments.
void* _Ad;
unsigned int _Bd;
unsigned int _Cd;